Author: mseidel
Date: Sat Jun 8 20:30:34 2019
New Revision: 1860845
URL: http://svn.apache.org/viewvc?rev=1860845&view=rev
Log:
Fixed typos (wether -> whether)
Modified:
openoffice/trunk/main/canvas/inc/canvas/rendering/isurface.hxx
openoffice/trunk/main/canvas/source/directx/dx_surfacebitmap.hxx
openoffice/trunk/main/chart2/source/controller/drawinglayer/DrawViewWrapper.cxx
openoffice/trunk/main/chart2/source/controller/main/ChartController_Window.cxx
openoffice/trunk/main/chart2/source/controller/main/PositionAndSizeHelper.cxx
openoffice/trunk/main/chart2/source/controller/main/SelectionHelper.cxx
openoffice/trunk/main/chart2/source/inc/chartview/ExplicitScaleValues.hxx
openoffice/trunk/main/chart2/source/model/main/ChartModel.cxx
openoffice/trunk/main/chart2/source/model/main/ChartModel_Persistence.cxx
openoffice/trunk/main/chart2/source/tools/AxisHelper.cxx
openoffice/trunk/main/chart2/source/tools/LifeTime.cxx
openoffice/trunk/main/chart2/source/view/axes/VAxisProperties.hxx
openoffice/trunk/main/chart2/source/view/charttypes/BarChart.cxx
openoffice/trunk/main/chart2/source/view/charttypes/BarChart.hxx
openoffice/trunk/main/chart2/source/view/charttypes/VSeriesPlotter.cxx
openoffice/trunk/main/chart2/source/view/inc/VCoordinateSystem.hxx
openoffice/trunk/main/chart2/source/view/inc/VDataSeries.hxx
openoffice/trunk/main/chart2/source/view/inc/VSeriesPlotter.hxx
openoffice/trunk/main/chart2/source/view/main/ChartView.cxx
openoffice/trunk/main/chart2/source/view/main/ChartView.hxx
openoffice/trunk/main/chart2/source/view/main/Clipping.cxx
openoffice/trunk/main/chart2/source/view/main/PolarLabelPositionHelper.cxx
openoffice/trunk/main/chart2/source/view/main/VLegend.cxx
openoffice/trunk/main/configure.ac
openoffice/trunk/main/connectivity/java/dbtools/build.xml
openoffice/trunk/main/connectivity/java/sdbc_hsqldb/build.xml
openoffice/trunk/main/connectivity/java/sdbc_jdbc/build.xml
openoffice/trunk/main/connectivity/java/sdbc_postgresql/build.xml
openoffice/trunk/main/cui/source/inc/dlgname.hxx
openoffice/trunk/main/cui/source/options/optdict.cxx
openoffice/trunk/main/dbaccess/source/ui/app/subcomponentmanager.cxx
openoffice/trunk/main/editeng/source/accessibility/AccessibleEditableTextPara.cxx
openoffice/trunk/main/io/test/stm/pumptest.cxx
openoffice/trunk/main/jurt/java/jurt/src/main/java/com/sun/star/comp/servicemanager/ServiceManager.java
openoffice/trunk/main/l10ntools/java/jpropex/build.xml
openoffice/trunk/main/l10ntools/java/l10nconv/build.xml
openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java
openoffice/trunk/main/l10ntools/java/receditor/build.xml
openoffice/trunk/main/l10ntools/source/tagtest.cxx
openoffice/trunk/main/linguistic/workben/sspellimp.cxx
openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/ComponentTreeTraversal.java
openoffice/trunk/main/offapi/com/sun/star/chart/XAxisSupplier.idl
openoffice/trunk/main/offapi/com/sun/star/chart2/Axis.idl
openoffice/trunk/main/offapi/com/sun/star/chart2/DataSeries.idl
openoffice/trunk/main/offapi/com/sun/star/chart2/IncrementData.idl
openoffice/trunk/main/offapi/com/sun/star/chart2/ScaleData.idl
openoffice/trunk/main/offapi/com/sun/star/chart2/XCoordinateSystem.idl
openoffice/trunk/main/offapi/com/sun/star/drawing/framework/XConfiguration.idl
openoffice/trunk/main/offapi/com/sun/star/report/ReportPrintOption.idl
openoffice/trunk/main/offapi/com/sun/star/report/XSection.idl
openoffice/trunk/main/offapi/com/sun/star/text/XTextTableCursor.idl
openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs
openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
openoffice/trunk/main/psprint_config/configuration/psprint.conf
openoffice/trunk/main/pyuno/inc/pyuno/pyuno.hxx
openoffice/trunk/main/reportdesign/source/core/sdr/UndoEnv.cxx
openoffice/trunk/main/sal/osl/os2/file_url.cxx
openoffice/trunk/main/sal/osl/os2/pipeimpl.h
openoffice/trunk/main/sal/osl/unx/thread.c
openoffice/trunk/main/sal/osl/w32/file_url.cxx
openoffice/trunk/main/sal/osl/w32/pipeimpl.h
openoffice/trunk/main/sd/source/ui/app/sdmod1.cxx
openoffice/trunk/main/sd/source/ui/dlg/TemplateScanner.cxx
openoffice/trunk/main/sd/source/ui/dlg/dlgass.cxx
openoffice/trunk/main/sd/source/ui/func/fupage.cxx
openoffice/trunk/main/sd/source/ui/slidesorter/cache/SlsQueueProcessorThread.hxx
openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsButtonBar.hxx
openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsInsertAnimator.hxx
openoffice/trunk/main/sdext/source/pdfimport/tree/writertreevisiting.cxx
openoffice/trunk/main/sfx2/qa/complex/sfx2/DocumentInfo.java
openoffice/trunk/main/sfx2/qa/complex/sfx2/GlobalEventBroadcaster.java
openoffice/trunk/main/sfx2/source/appl/appopen.cxx
openoffice/trunk/main/sfx2/source/control/dispatch.cxx
openoffice/trunk/main/sfx2/source/dialog/filedlghelper.cxx
openoffice/trunk/main/sfx2/source/doc/docinsert.cxx
openoffice/trunk/main/sfx2/source/doc/doctempl.cxx
openoffice/trunk/main/sfx2/source/doc/doctemplates.cxx
openoffice/trunk/main/sfx2/source/view/ipclient.cxx
openoffice/trunk/main/sfx2/source/view/viewfrm.cxx
openoffice/trunk/main/shell/source/unix/exec/shellexec.cxx
openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.cxx
openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.hxx
openoffice/trunk/main/svx/source/form/fmundo.cxx
openoffice/trunk/main/sw/source/core/doc/htmltbl.cxx
openoffice/trunk/main/sw/source/ui/inc/swuiidxmrk.hxx
openoffice/trunk/main/sw/source/ui/index/swuiidxmrk.cxx
openoffice/trunk/main/tools/inc/tools/debug.hxx
openoffice/trunk/main/ucb/source/cacher/cachedcontentresultsetstub.cxx
openoffice/trunk/main/unotools/source/ucbhelper/ucblockbytes.cxx
openoffice/trunk/main/vcl/inc/vcl/fontmanager.hxx
openoffice/trunk/main/vcl/inc/vcl/outdev.hxx
openoffice/trunk/main/vcl/source/window/window.cxx
openoffice/trunk/main/vcl/unx/generic/app/saldisp.cxx
openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.cxx
openoffice/trunk/main/vcl/unx/generic/fontmanager/fontmanager.cxx
openoffice/trunk/main/vcl/unx/generic/gdi/salprnpsp.cxx
openoffice/trunk/main/vcl/unx/generic/printergfx/psheader.ps
openoffice/trunk/main/vcl/unx/headless/svpprn.cxx
openoffice/trunk/main/wizards/com/sun/star/wizards/ui/SortingComponent.java
openoffice/trunk/main/wizards/source/tools/Misc.xba
openoffice/trunk/main/xmerge/source/inc/antbuild.properties
openoffice/trunk/main/xmerge/workben/build.xml
openoffice/trunk/main/xmloff/source/chart/SchXMLChartContext.hxx
openoffice/trunk/main/xmloff/source/meta/xmlversion.cxx
openoffice/trunk/main/xmloff/source/style/styleexp.cxx
Modified: openoffice/trunk/main/canvas/inc/canvas/rendering/isurface.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/rendering/isurface.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/rendering/isurface.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/rendering/isurface.hxx Sat Jun 8
20:30:34 2019
@@ -49,7 +49,7 @@ namespace canvas
*/
virtual bool selectTexture() = 0;
- /** Tells wether the surface is valid or not
+ /** Tells whether the surface is valid or not
*/
virtual bool isValid() = 0;
Modified: openoffice/trunk/main/canvas/source/directx/dx_surfacebitmap.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/directx/dx_surfacebitmap.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/model/main/ChartModel.cxx (original)
+++ openoffice/trunk/main/chart2/source/model/main/ChartModel.cxx Sat Jun 8
20:30:34 2019
@@ -632,7 +632,7 @@ void SAL_CALL ChartModel::close( sal_Boo
uno::Reference< uno::XInterface > xSelfHold( static_cast<
::cppu::OWeakObject* >(this) );
//the listeners have had no veto
- //check wether we self can close
+ //check whether we self can close
{
util::CloseVetoException aVetoException =
util::CloseVetoException(
::rtl::OUString(
RTL_CONSTASCII_USTRINGPARAM(
Modified:
openoffice/trunk/main/chart2/source/model/main/ChartModel_Persistence.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/model/main/ChartModel_Persistence.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/model/main/ChartModel_Persistence.cxx
(original)
+++ openoffice/trunk/main/chart2/source/model/main/ChartModel_Persistence.cxx
Sat Jun 8 20:30:34 2019
@@ -257,7 +257,7 @@ void SAL_CALL ChartModel::store()
if( aLocation.isEmpty() )
throw io::IOException( C2U( "no location specified" ),
static_cast< ::cppu::OWeakObject* >(this));
- //@todo check wether aLocation is something like private:factory...
+ //@todo check whether aLocation is something like private:factory...
if( m_bReadOnly )
throw io::IOException( C2U( "document is read only" ),
static_cast< ::cppu::OWeakObject* >(this));
Modified: openoffice/trunk/main/chart2/source/tools/AxisHelper.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/tools/AxisHelper.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/tools/AxisHelper.cxx (original)
+++ openoffice/trunk/main/chart2/source/tools/AxisHelper.cxx Sat Jun 8
20:30:34 2019
@@ -159,7 +159,7 @@ sal_Int32 AxisHelper::getExplicitNumberF
if( xProp.is() && !( xProp->getPropertyValue( C2U( "NumberFormat" ) ) >>=
nNumberFormatKey ) )
{
bool bFormatSet = false;
- //check wether we have a percent scale -> use percent format
+ //check whether we have a percent scale -> use percent format
if( xNumberFormatsSupplier.is() )
{
ScaleData aData = AxisHelper::getDateCheckedScale( xAxis,
Reference< frame::XModel >( xNumberFormatsSupplier, uno::UNO_QUERY ) );
Modified: openoffice/trunk/main/chart2/source/tools/LifeTime.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/tools/LifeTime.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/tools/LifeTime.cxx (original)
+++ openoffice/trunk/main/chart2/source/tools/LifeTime.cxx Sat Jun 8 20:30:34
2019
@@ -503,7 +503,7 @@ the XCloseable::close method has to be i
uno::Reference< uno::XInterface > xSelfHold( static_cast<
::cppu::OWeakObject* >(this) );
//the listeners have had no veto
- //check wether we self can close
+ //check whether we self can close
{
util::CloseVetoException aVetoException =
util::CloseVetoException(
::rtl::OUString(
RTL_CONSTASCII_USTRINGPARAM(
Modified: openoffice/trunk/main/chart2/source/view/axes/VAxisProperties.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/axes/VAxisProperties.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/axes/VAxisProperties.hxx (original)
+++ openoffice/trunk/main/chart2/source/view/axes/VAxisProperties.hxx Sat Jun
8 20:30:34 2019
@@ -81,7 +81,7 @@ struct AxisLabelProperties
double fRotationAngleDegree;
sal_Int32 nRhythm; //show only each nth label with n==nRhythm
- bool bRhythmIsFix; //states wether the given rhythm is fix or may
be changed
+ bool bRhythmIsFix; //states whether the given rhythm is fix or may
be changed
//methods:
void init( const ::com::sun::star::uno::Reference<
Modified: openoffice/trunk/main/chart2/source/view/charttypes/BarChart.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/charttypes/BarChart.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/charttypes/BarChart.cxx (original)
+++ openoffice/trunk/main/chart2/source/view/charttypes/BarChart.cxx Sat Jun 8
20:30:34 2019
@@ -590,7 +590,7 @@ void BarChart::createShapes()
bDrawConnectionLines = false;
if( bDrawConnectionLines && pSeriesList->size()==1 )
{
- //detect wether we have a stacked chart or not:
+ //detect whether we have a stacked chart or not:
StackingDirection eDirection =
pSeries->getStackingDirection();
if( eDirection != StackingDirection_Y_STACKING )
bDrawConnectionLines = false;
Modified: openoffice/trunk/main/chart2/source/view/charttypes/BarChart.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/charttypes/BarChart.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/charttypes/BarChart.hxx (original)
+++ openoffice/trunk/main/chart2/source/view/charttypes/BarChart.hxx Sat Jun 8
20:30:34 2019
@@ -75,7 +75,7 @@ private: //methods
, double fScaledLowerBarDepth, double
fScaledUpperBarDepth, double fBaseValue
, BarPositionHelper* pPosHelper ) const;
- virtual PlottingPositionHelper& getPlottingPositionHelper( sal_Int32
nAxisIndex ) const;//nAxisIndex indicates wether the position belongs to the
main axis ( nAxisIndex==0 ) or secondary axis ( nAxisIndex==1 )
+ virtual PlottingPositionHelper& getPlottingPositionHelper( sal_Int32
nAxisIndex ) const;//nAxisIndex indicates whether the position belongs to the
main axis ( nAxisIndex==0 ) or secondary axis ( nAxisIndex==1 )
void adaptOverlapAndGapwidthForGroupBarsPerAxis();
Modified: openoffice/trunk/main/chart2/source/view/charttypes/VSeriesPlotter.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/charttypes/VSeriesPlotter.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/charttypes/VSeriesPlotter.cxx
(original)
+++ openoffice/trunk/main/chart2/source/view/charttypes/VSeriesPlotter.cxx Sat
Jun 8 20:30:34 2019
@@ -448,7 +448,7 @@ uno::Reference< drawing::XShape > VSerie
m_pShapeFactory->createGroup2D(
this->getLabelsGroupShape(rDataSeries, xTarget)
, ObjectIdentifier::createPointCID(
rDataSeries.getLabelCID_Stub(),nPointIndex ) ) );
- //check wether the label needs to be created and how:
+ //check whether the label needs to be created and how:
DataPointLabel* pLabel = rDataSeries.getDataPointLabelIfLabel(
nPointIndex );
if( !pLabel )
@@ -1117,7 +1117,7 @@ void VSeriesPlotter::createRegressionCur
chart2::RelativePosition aRelativePosition;
if( xEquationProperties->getPropertyValue( C2U("RelativePosition"))
>>= aRelativePosition )
{
- //@todo decide wether x is primary or secondary
+ //@todo decide whether x is primary or secondary
double fX = aRelativePosition.Primary*m_aPageReferenceSize.Width;
double fY =
aRelativePosition.Secondary*m_aPageReferenceSize.Height;
aScreenPosition2D.X = static_cast< sal_Int32 >(
::rtl::math::round( fX ));
Modified: openoffice/trunk/main/chart2/source/view/inc/VCoordinateSystem.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/inc/VCoordinateSystem.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/inc/VCoordinateSystem.hxx
(original)
+++ openoffice/trunk/main/chart2/source/view/inc/VCoordinateSystem.hxx Sat Jun
8 20:30:34 2019
@@ -160,7 +160,7 @@ protected: //member
rtl::OUString m_aCooSysParticle;
- typedef std::pair< sal_Int32, sal_Int32 > tFullAxisIndex; //first index is
the dimension, second index is the axis index that indicates wether this is a
main or secondary axis
+ typedef std::pair< sal_Int32, sal_Int32 > tFullAxisIndex; //first index is
the dimension, second index is the axis index that indicates whether this is a
main or secondary axis
//
::com::sun::star::uno::Reference<
Modified: openoffice/trunk/main/chart2/source/view/inc/VDataSeries.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/inc/VDataSeries.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/inc/VDataSeries.hxx (original)
+++ openoffice/trunk/main/chart2/source/view/inc/VDataSeries.hxx Sat Jun 8
20:30:34 2019
@@ -219,7 +219,7 @@ private: //member
::com::sun::star::chart2::StackingDirection m_eStackingDirection;
- sal_Int32 m_nAxisIndex;//indicates wether this is attached
to a main or secondary axis
+ sal_Int32 m_nAxisIndex;//indicates whether this is attached
to a main or secondary axis
sal_Bool m_bConnectBars;
Modified: openoffice/trunk/main/chart2/source/view/inc/VSeriesPlotter.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/inc/VSeriesPlotter.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/inc/VSeriesPlotter.hxx (original)
+++ openoffice/trunk/main/chart2/source/view/inc/VSeriesPlotter.hxx Sat Jun 8
20:30:34 2019
@@ -402,7 +402,7 @@ protected: //methods
, const tPropertyNameMap& rMap
, tPropertyNameValueMap* pOverwriteMap=0 );
- virtual PlottingPositionHelper& getPlottingPositionHelper( sal_Int32
nAxisIndex ) const;//nAxisIndex indicates wether the position belongs to the
main axis ( nAxisIndex==0 ) or secondary axis ( nAxisIndex==1 )
+ virtual PlottingPositionHelper& getPlottingPositionHelper( sal_Int32
nAxisIndex ) const;//nAxisIndex indicates whether the position belongs to the
main axis ( nAxisIndex==0 ) or secondary axis ( nAxisIndex==1 )
VDataSeries* getFirstSeries() const;
Modified: openoffice/trunk/main/chart2/source/view/main/ChartView.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/main/ChartView.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/main/ChartView.cxx (original)
+++ openoffice/trunk/main/chart2/source/view/main/ChartView.cxx Sat Jun 8
20:30:34 2019
@@ -455,7 +455,7 @@ VCoordinateSystem* lcl_getCooSysForPlott
return 0;
}
-typedef std::pair< sal_Int32, sal_Int32 > tFullAxisIndex; //first index is the
dimension, second index is the axis index that indicates wether this is a main
or secondary axis
+typedef std::pair< sal_Int32, sal_Int32 > tFullAxisIndex; //first index is the
dimension, second index is the axis index that indicates whether this is a main
or secondary axis
typedef std::pair< VCoordinateSystem* , tFullAxisIndex > tFullCoordinateSystem;
typedef std::map< VCoordinateSystem*, tFullAxisIndex > tCoordinateSystemMap;
@@ -1948,7 +1948,7 @@ awt::Rectangle ExplicitValueProvider::ad
ExplicitValueProvider* pExplicitValueProvider =
ExplicitValueProvider::getExplicitValueProvider(xChartView);
if( pExplicitValueProvider )
{
- //detect wether x axis points into x direction or not
+ //detect whether x axis points into x direction or not
if( lcl_getPropertySwapXAndYAxis( ChartModelHelper::findDiagram(
xChartModel ) ) )
{
std::swap( xTitle_Height, xTitle_Width );
@@ -2015,7 +2015,7 @@ awt::Rectangle ExplicitValueProvider::su
ExplicitValueProvider* pExplicitValueProvider =
ExplicitValueProvider::getExplicitValueProvider(xChartView);
if( pExplicitValueProvider )
{
- //detect wether x axis points into x direction or not
+ //detect whether x axis points into x direction or not
if( lcl_getPropertySwapXAndYAxis( ChartModelHelper::findDiagram(
xChartModel ) ) )
{
std::swap( xTitle_Height, xTitle_Width );
@@ -2113,7 +2113,7 @@ bool getAvailablePosAndSizeForDiagram(
chart2::RelativePosition aRelativePosition;
if( xProp.is() && (xProp->getPropertyValue( C2U( "RelativePosition" )
)>>=aRelativePosition) )
{
- //@todo decide wether x is primary or secondary
+ //@todo decide whether x is primary or secondary
//the coordinates re relative to the page
double fX = aRelativePosition.Primary*rPageSize.Width;
@@ -2244,7 +2244,7 @@ std::auto_ptr<VTitle> lcl_createTitle( T
{
rbAutoPosition = false;
- //@todo decide wether x is primary or secondary
+ //@todo decide whether x is primary or secondary
double fX = aRelativePosition.Primary*rPageSize.Width;
double fY = aRelativePosition.Secondary*rPageSize.Height;
Modified: openoffice/trunk/main/chart2/source/view/main/ChartView.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/main/ChartView.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/main/ChartView.hxx (original)
+++ openoffice/trunk/main/chart2/source/view/main/ChartView.hxx Sat Jun 8
20:30:34 2019
@@ -230,7 +230,7 @@ private: //member
::cppu::OMultiTypeInterfaceContainerHelper
m_aListenerContainer;
- bool volatile m_bViewDirty; //states wether the view needs to be
rebuild
+ bool volatile m_bViewDirty; //states whether the view needs to be
rebuild
bool volatile m_bInViewUpdate;
bool volatile m_bViewUpdatePending;
bool volatile m_bRefreshAddIn;
Modified: openoffice/trunk/main/chart2/source/view/main/Clipping.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/main/Clipping.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/main/Clipping.cxx (original)
+++ openoffice/trunk/main/chart2/source/view/main/Clipping.cxx Sat Jun 8
20:30:34 2019
@@ -110,7 +110,7 @@ bool lcl_clip2d(B2DTuple& rPoint0, B2DTu
double fTE = 0,
fTL = 1;
- // Test wether at least a part lies in the four
half-planes with respect to
+ // Test whether at least a part lies in the four
half-planes with respect to
// the rectangles four edges.
if( lcl_CLIPt(aDirection.getX(), rRectangle.getMinX() -
rPoint0.getX(), fTE, fTL) )
if( lcl_CLIPt(-aDirection.getX(), rPoint0.getX() -
rRectangle.getMaxX(), fTE, fTL) )
Modified:
openoffice/trunk/main/chart2/source/view/main/PolarLabelPositionHelper.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/main/PolarLabelPositionHelper.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/main/PolarLabelPositionHelper.cxx
(original)
+++ openoffice/trunk/main/chart2/source/view/main/PolarLabelPositionHelper.cxx
Sat Jun 8 20:30:34 2019
@@ -91,7 +91,7 @@ awt::Point PolarLabelPositionHelper::get
if(3==m_nDimensionCount && nLabelPlacement ==
::com::sun::star::chart::DataLabelPlacement::OUTSIDE)
{
- //check wether the upper or the downer edge is more distant from the
center
+ //check whether the upper or the downer edge is more distant from the
center
//take the farest point to put the label to
awt::Point aP0( this->transformSceneToScreenPosition(
Modified: openoffice/trunk/main/chart2/source/view/main/VLegend.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/main/VLegend.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/main/VLegend.cxx (original)
+++ openoffice/trunk/main/chart2/source/view/main/VLegend.cxx Sat Jun 8
20:30:34 2019
@@ -375,7 +375,7 @@ awt::Size lcl_placeLegendEntries(
nCurrentColumn++;
if( nCurrentColumn < nCurrentColumnCount )
{
- //check wether the current column width is sufficient for
the new entry
+ //check whether the current column width is sufficient for
the new entry
if( aColumnWidths[nCurrentColumn]>=nNewWidth )
{
//all good proceed with next entry
Modified: openoffice/trunk/main/configure.ac
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/configure.ac?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/configure.ac (original)
+++ openoffice/trunk/main/configure.ac Sat Jun 8 20:30:34 2019
@@ -4519,7 +4519,7 @@ if test "x$enable_coinmp" = "xyes"; then
AC_MSG_RESULT([yes])
ENABLE_COINMP=YES
- dnl Check wether to use system or internal CoinMP
+ dnl Check whether to use system or internal CoinMP
AC_MSG_CHECKING([which coinmp to use])
if test "x$with_system_coinmp" = "xyes" -o -n "$with_system_libs"; then
AC_MSG_RESULT([system])
Modified: openoffice/trunk/main/connectivity/java/dbtools/build.xml
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/java/dbtools/build.xml?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/java/dbtools/build.xml (original)
+++ openoffice/trunk/main/connectivity/java/dbtools/build.xml Sat Jun 8
20:30:34 2019
@@ -84,13 +84,13 @@
<!-- set "modern" java compiler -->
<property name="build.compiler" value="modern"/>
- <!-- set wether we want to compile with debug information -->
+ <!-- set whether we want to compile with debug information -->
<property name="debug" value="on"/>
- <!-- set wether we want to compile with optimisation -->
+ <!-- set whether we want to compile with optimisation -->
<property name="optimize" value="off"/>
- <!-- set wether we want to compile with or without deprecation -->
+ <!-- set whether we want to compile with or without deprecation -->
<property name="deprecation" value="on"/>
<target name="info">
Modified: openoffice/trunk/main/connectivity/java/sdbc_hsqldb/build.xml
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/java/sdbc_hsqldb/build.xml?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/java/sdbc_hsqldb/build.xml (original)
+++ openoffice/trunk/main/connectivity/java/sdbc_hsqldb/build.xml Sat Jun 8
20:30:34 2019
@@ -78,13 +78,13 @@
<!-- set "modern" java compiler -->
<property name="build.compiler" value="modern"/>
- <!-- set wether we want to compile with debug information -->
+ <!-- set whether we want to compile with debug information -->
<property name="debug" value="on"/>
- <!-- set wether we want to compile with optimisation -->
+ <!-- set whether we want to compile with optimisation -->
<property name="optimize" value="off"/>
- <!-- set wether we want to compile with or without deprecation -->
+ <!-- set whether we want to compile with or without deprecation -->
<property name="deprecation" value="on"/>
<target name="info">
Modified: openoffice/trunk/main/connectivity/java/sdbc_jdbc/build.xml
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/java/sdbc_jdbc/build.xml?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/java/sdbc_jdbc/build.xml (original)
+++ openoffice/trunk/main/connectivity/java/sdbc_jdbc/build.xml Sat Jun 8
20:30:34 2019
@@ -85,13 +85,13 @@
<!-- set "modern" java compiler -->
<property name="build.compiler" value="modern"/>
- <!-- set wether we want to compile with debug information -->
+ <!-- set whether we want to compile with debug information -->
<property name="debug" value="on"/>
- <!-- set wether we want to compile with optimisation -->
+ <!-- set whether we want to compile with optimisation -->
<property name="optimize" value="off"/>
- <!-- set wether we want to compile with or without deprecation -->
+ <!-- set whether we want to compile with or without deprecation -->
<property name="deprecation" value="on"/>
<target name="info">
Modified: openoffice/trunk/main/connectivity/java/sdbc_postgresql/build.xml
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/connectivity/java/sdbc_postgresql/build.xml?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/connectivity/java/sdbc_postgresql/build.xml (original)
+++ openoffice/trunk/main/connectivity/java/sdbc_postgresql/build.xml Sat Jun
8 20:30:34 2019
@@ -77,13 +77,13 @@
<!-- set "modern" java compiler -->
<property name="build.compiler" value="modern"/>
- <!-- set wether we want to compile with debug information -->
+ <!-- set whether we want to compile with debug information -->
<property name="debug" value="on"/>
- <!-- set wether we want to compile with optimisation -->
+ <!-- set whether we want to compile with optimisation -->
<property name="optimize" value="off"/>
- <!-- set wether we want to compile with or without deprecation -->
+ <!-- set whether we want to compile with or without deprecation -->
<property name="deprecation" value="on"/>
<target name="info">
Modified: openoffice/trunk/main/cui/source/inc/dlgname.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/cui/source/inc/dlgname.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/cui/source/inc/dlgname.hxx (original)
+++ openoffice/trunk/main/cui/source/inc/dlgname.hxx Sat Jun 8 20:30:34 2019
@@ -66,7 +66,7 @@ public:
void GetName( String& rName ){rName = aEdtName.GetText();}
/** add a callback Link that is called whenever the content of the edit
- field is changed. The Link result determines wether the OK
+ field is changed. The Link result determines whether the OK
Button is enabled (> 0) or disabled (== 0).
@param rLink a Callback declared with DECL_LINK and implemented with
Modified: openoffice/trunk/main/cui/source/options/optdict.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/cui/source/options/optdict.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/cui/source/options/optdict.cxx (original)
+++ openoffice/trunk/main/cui/source/options/optdict.cxx Sat Jun 8 20:30:34
2019
@@ -616,7 +616,7 @@ IMPL_LINK(SvxEditDictionaryDialog, NewDe
{
// make changes in dic
- //! ...IsVisible should reflect wether the
dictionary is a negativ
+ //! ...IsVisible should reflect whether the
dictionary is a negativ
//! or not (hopefully...)
sal_Bool bIsNegEntry = aReplaceFT.IsVisible();
::rtl::OUString aRplcText;
Modified: openoffice/trunk/main/dbaccess/source/ui/app/subcomponentmanager.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/dbaccess/source/ui/app/subcomponentmanager.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/dbaccess/source/ui/app/subcomponentmanager.cxx
(original)
+++ openoffice/trunk/main/dbaccess/source/ui/app/subcomponentmanager.cxx Sat
Jun 8 20:30:34 2019
@@ -165,7 +165,7 @@ namespace dbaui
xController.set( xFrame->getController(),
UNO_SET_THROW );
}
- // check wether there is a model (not required)
+ // check whether there is a model (not required)
xModel.set( xController->getModel() );
}
Modified:
openoffice/trunk/main/editeng/source/accessibility/AccessibleEditableTextPara.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/editeng/source/accessibility/AccessibleEditableTextPara.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/editeng/source/accessibility/AccessibleEditableTextPara.cxx
(original)
+++
openoffice/trunk/main/editeng/source/accessibility/AccessibleEditableTextPara.cxx
Sat Jun 8 20:30:34 2019
@@ -758,7 +758,7 @@ namespace accessibility
!pStateSet->contains(nStateId) )
{
pStateSet->AddState( nStateId );
- // MT: Removed method IsShapeParaFocusable which was introduced
with IA2 - basically it was only about figuring out wether or not the window
has the focus, should be solved differently
+ // MT: Removed method IsShapeParaFocusable which was introduced
with IA2 - basically it was only about figuring out whether or not the window
has the focus, should be solved differently
// if(IsShapeParaFocusable())
GotPropertyEvent( uno::makeAny( nStateId ),
AccessibleEventId::STATE_CHANGED );
}
Modified: openoffice/trunk/main/io/test/stm/pumptest.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/io/test/stm/pumptest.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/io/test/stm/pumptest.cxx (original)
+++ openoffice/trunk/main/io/test/stm/pumptest.cxx Sat Jun 8 20:30:34 2019
@@ -377,7 +377,7 @@ void OPumpTest::testTerminate( const Ref
ERROR_ASSERT( t.m_pTestListener->m_bStarted , "should have been started
already" );
ERROR_ASSERT( t.m_pTestListener->m_bTerminated , "should be terminiated
already" );
// terminte leads to an error, that is no surprise, in fact
- // one can't tell wether the error occurs because of the terminate
+ // one can't tell whether the error occurs because of the terminate
// call or for some other reason !
// ERROR_ASSERT( ! t.m_pTestListener->m_bError, "unexpected error" );
ERROR_ASSERT( t.m_pTestListener->m_bClosed, "should be closed already" );
Modified:
openoffice/trunk/main/jurt/java/jurt/src/main/java/com/sun/star/comp/servicemanager/ServiceManager.java
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/jurt/java/jurt/src/main/java/com/sun/star/comp/servicemanager/ServiceManager.java?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/jurt/java/jurt/src/main/java/com/sun/star/comp/servicemanager/ServiceManager.java
(original)
+++
openoffice/trunk/main/jurt/java/jurt/src/main/java/com/sun/star/comp/servicemanager/ServiceManager.java
Sat Jun 8 20:30:34 2019
@@ -837,7 +837,7 @@ class ServiceManagerFactory implements
}
/**
- * Checks wether or not a service is supported.
+ * Checks whether or not a service is supported.
* <p>
* @return true - if the service is supported, otherwise
false.
* @param serviceName the name of the service
that should be checked.
Modified: openoffice/trunk/main/l10ntools/java/jpropex/build.xml
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/jpropex/build.xml?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/jpropex/build.xml (original)
+++ openoffice/trunk/main/l10ntools/java/jpropex/build.xml Sat Jun 8 20:30:34
2019
@@ -62,13 +62,13 @@
<!-- set "modern" java compiler -->
<property name="build.compiler" value="modern"/>
- <!-- set wether we want to compile with debug information -->
+ <!-- set whether we want to compile with debug information -->
<property name="debug" value="on"/>
- <!-- set wether we want to compile with optimisation -->
+ <!-- set whether we want to compile with optimisation -->
<property name="optimize" value="off"/>
- <!-- set wether we want to compile with or without deprecation -->
+ <!-- set whether we want to compile with or without deprecation -->
<property name="deprecation" value="on"/>
<target name="info">
Modified: openoffice/trunk/main/l10ntools/java/l10nconv/build.xml
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/l10nconv/build.xml?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/l10nconv/build.xml (original)
+++ openoffice/trunk/main/l10ntools/java/l10nconv/build.xml Sat Jun 8 20:30:34
2019
@@ -62,13 +62,13 @@
<!-- set "modern" java compiler -->
<property name="build.compiler" value="modern"/>
- <!-- set wether we want to compile with debug information -->
+ <!-- set whether we want to compile with debug information -->
<property name="debug" value="on"/>
- <!-- set wether we want to compile with optimisation -->
+ <!-- set whether we want to compile with optimisation -->
<property name="optimize" value="off"/>
- <!-- set wether we want to compile with or without deprecation -->
+ <!-- set whether we want to compile with or without deprecation -->
<property name="deprecation" value="on"/>
<target name="info">
Modified:
openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java
(original)
+++
openoffice/trunk/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java
Sat Jun 8 20:30:34 2019
@@ -45,7 +45,7 @@ public final class FileMaker {
* ask if existing files should be overwritten
*
* @param fileName the files name to overwrite
- * @param overwrite indicates wether the file can be overwritten
+ * @param overwrite indicates whether the file can be overwritten
* @return the File created from the fileName
* @throws IOException
*/
Modified: openoffice/trunk/main/l10ntools/java/receditor/build.xml
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/java/receditor/build.xml?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/java/receditor/build.xml (original)
+++ openoffice/trunk/main/l10ntools/java/receditor/build.xml Sat Jun 8
20:30:34 2019
@@ -62,13 +62,13 @@
<!-- set "modern" java compiler -->
<property name="build.compiler" value="modern"/>
- <!-- set wether we want to compile with debug information -->
+ <!-- set whether we want to compile with debug information -->
<property name="debug" value="on"/>
- <!-- set wether we want to compile with optimisation -->
+ <!-- set whether we want to compile with optimisation -->
<property name="optimize" value="off"/>
- <!-- set wether we want to compile with or without deprecation -->
+ <!-- set whether we want to compile with or without deprecation -->
<property name="deprecation" value="on"/>
<target name="info">
Modified: openoffice/trunk/main/l10ntools/source/tagtest.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/tagtest.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/tagtest.cxx (original)
+++ openoffice/trunk/main/l10ntools/source/tagtest.cxx Sat Jun 8 20:30:34 2019
@@ -447,7 +447,7 @@ sal_Bool TokenInfo::MatchesTranslation(
{
// check if tags are equal
// check if all existing properties are in the translation as well and
- // wether they have a matching content (the same in most cases)
+ // whether they have a matching content (the same in most cases)
if ( nId != rInfo.nId )
return sal_False;
Modified: openoffice/trunk/main/linguistic/workben/sspellimp.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/linguistic/workben/sspellimp.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/linguistic/workben/sspellimp.cxx (original)
+++ openoffice/trunk/main/linguistic/workben/sspellimp.cxx Sat Jun 8 20:30:34
2019
@@ -134,7 +134,7 @@ sal_Bool SAL_CALL SpellChecker::hasLocal
INT16 SpellChecker::GetSpellFailure( const OUString &rWord, const Locale
&rLocale )
{
- // Checks wether a word is OK in a given language (Locale) or not, and
+ // Checks whether a word is OK in a given language (Locale) or not, and
// provides a failure type for the incorrect ones.
// - words with "liss" (case sensitiv) as substring will be negative.
// - words with 'x' or 'X' will have incorrect spelling.
Modified:
openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/ComponentTreeTraversal.java
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/ComponentTreeTraversal.java?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/ComponentTreeTraversal.java
(original)
+++
openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/ComponentTreeTraversal.java
Sat Jun 8 20:30:34 2019
@@ -39,7 +39,7 @@ interface IFormComponentAction
class ComponentTreeTraversal implements IFormComponentAction
{
/* ------------------------------------------------------------------ */
- /** Indicator method to decide wether to step down the tree.
+ /** Indicator method to decide whether to step down the tree.
<p>The default implementation checks if the container given is
a grid
control model or a <service
scope="com.sun.star.form">FormComponents</service>
Modified: openoffice/trunk/main/offapi/com/sun/star/chart/XAxisSupplier.idl
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/chart/XAxisSupplier.idl?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/chart/XAxisSupplier.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/chart/XAxisSupplier.idl Sat Jun
8 20:30:34 2019
@@ -39,7 +39,7 @@ interface XAxisSupplier : ::com::sun::st
the primary axis of the specified dimension. The returned
object supports service <type>ChartAxis</type>.
@param nDimensionIndex
- Parameter nDimensionIndex says wether it is a x, y or z-axis (0
for x).
+ Parameter nDimensionIndex says whether it is a x, y or z-axis (0
for x).
*/
com::sun::star::chart::XAxis getAxis( [in] long nDimensionIndex );
@@ -47,7 +47,7 @@ interface XAxisSupplier : ::com::sun::st
the secondary axis of the specified dimension. The returned
object supports service <type>ChartAxis</type>.
@param nDimensionIndex
- Parameter nDimensionIndex says wether it is a x, y or z-axis (0
for x).
+ Parameter nDimensionIndex says whether it is a x, y or z-axis (0
for x).
*/
com::sun::star::chart::XAxis getSecondaryAxis( [in] long nDimensionIndex );
};
Modified: openoffice/trunk/main/offapi/com/sun/star/chart2/Axis.idl
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/chart2/Axis.idl?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/chart2/Axis.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/chart2/Axis.idl Sat Jun 8
20:30:34 2019
@@ -83,15 +83,15 @@ service Axis
*/
[property] ::com::sun::star::chart::ChartAxisArrangeOrderType
ArrangeOrder;
- /** Determines wether the labels are allowed to break into more than one
line
+ /** Determines whether the labels are allowed to break into more than one
line
*/
[property] boolean TextBreak;
- /** Determines wether the labels are allowed to overlap
+ /** Determines whether the labels are allowed to overlap
*/
[property] boolean TextOverlap;
- /** Determines wether the characters in a single labels should be stacked
one upon each other
+ /** Determines whether the characters in a single labels should be stacked
one upon each other
*/
[property] boolean StackCharacters;
Modified: openoffice/trunk/main/offapi/com/sun/star/chart2/DataSeries.idl
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/chart2/DataSeries.idl?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/chart2/DataSeries.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/chart2/DataSeries.idl Sat Jun 8
20:30:34 2019
@@ -159,7 +159,7 @@ service DataSeries
*/
[readonly, optional, property] sequence< long > AttributedDataPoints;
- /** indicates wether this series should be stacked with respect to the
previous series.
+ /** indicates whether this series should be stacked with respect to the
previous series.
*/
[property] StackingDirection StackingDirection;
@@ -168,7 +168,7 @@ service DataSeries
*/
[optional, property] boolean VaryColorsByPoint;
- /** This property describes wether the series should be shown at
+ /** This property describes whether the series should be shown at
the main value axis or at the secondary value axis. Having
this property not set or setting it to 0 means that this data
series will be scaled at the primary y-axis ( of the
Modified: openoffice/trunk/main/offapi/com/sun/star/chart2/IncrementData.idl
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/chart2/IncrementData.idl?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/chart2/IncrementData.idl
(original)
+++ openoffice/trunk/main/offapi/com/sun/star/chart2/IncrementData.idl Sat Jun
8 20:30:34 2019
@@ -48,7 +48,7 @@ struct IncrementData
any Distance;
/**
- <member>PostEquidistant</member> rules wether the member
<member>Distance</member>
+ <member>PostEquidistant</member> rules whether the member
<member>Distance</member>
describes a distance before or after the scaling is applied.
<p>If <member>PostEquidistant</member> equals <TRUE/>
<member>Distance</member>
Modified: openoffice/trunk/main/offapi/com/sun/star/chart2/ScaleData.idl
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/chart2/ScaleData.idl?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/chart2/ScaleData.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/chart2/ScaleData.idl Sat Jun 8
20:30:34 2019
@@ -93,7 +93,7 @@ struct ScaleData
*/
boolean AutoDateAxis;
- /** describes wether data points on category or date axis are placed
between tickmarks or not
+ /** describes whether data points on category or date axis are placed
between tickmarks or not
if true the maximum on the scale will be expanded for one interval
*/
boolean ShiftedCategoryPosition;
Modified: openoffice/trunk/main/offapi/com/sun/star/chart2/XCoordinateSystem.idl
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/chart2/XCoordinateSystem.idl?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/chart2/XCoordinateSystem.idl
(original)
+++ openoffice/trunk/main/offapi/com/sun/star/chart2/XCoordinateSystem.idl Sat
Jun 8 20:30:34 2019
@@ -59,8 +59,8 @@ interface XCoordinateSystem : ::com::sun
*/
string getViewServiceName();
- /** The dimension says wether it is a x, y or z axis.
- The index says wether it is a primary or a secondary axis.
+ /** The dimension says whether it is a x, y or z axis.
+ The index says whether it is a primary or a secondary axis.
Use nIndex == 0 for a primary axis.
*/
void setAxisByDimension( [in] long nDimension,
@@ -68,8 +68,8 @@ interface XCoordinateSystem : ::com::sun
[in] long nIndex )
raises( com::sun::star::lang::IndexOutOfBoundsException );
- /** The dimension says wether it is a x, y or z axis.
- The index indicates wether it is a primary or a secondary axis or
maybe more in future.
+ /** The dimension says whether it is a x, y or z axis.
+ The index indicates whether it is a primary or a secondary axis or
maybe more in future.
Use nIndex == 0 for a primary axis.
An empty Reference will be returned if the given nDimension and nIndex
are in the valid range but no axis is set for those values.
An IndexOutOfBoundsException will be thrown if nDimension is lower
than 0 or greater than the value returned by getDimension()
Modified:
openoffice/trunk/main/offapi/com/sun/star/drawing/framework/XConfiguration.idl
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/drawing/framework/XConfiguration.idl?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/offapi/com/sun/star/drawing/framework/XConfiguration.idl
(original)
+++
openoffice/trunk/main/offapi/com/sun/star/drawing/framework/XConfiguration.idl
Sat Jun 8 20:30:34 2019
@@ -86,7 +86,7 @@ published interface XConfiguration
[in] string sTargetURLPrefix,
[in] AnchorBindingMode eSearchMode);
- /** <p>Returns wether the specified resource is part of the
+ /** <p>Returns whether the specified resource is part of the
configuration.</p>
This is independent of whether the resource does really exist and is
active, i.e. has a visible representation in the GUI.
Modified: openoffice/trunk/main/offapi/com/sun/star/report/ReportPrintOption.idl
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/report/ReportPrintOption.idl?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/report/ReportPrintOption.idl
(original)
+++ openoffice/trunk/main/offapi/com/sun/star/report/ReportPrintOption.idl Sat
Jun 8 20:30:34 2019
@@ -30,7 +30,7 @@
//=============================================================================
-/** Specifies wether a page header or footer is printed on the same page as
the report header or report footer.
+/** Specifies whether a page header or footer is printed on the same page as
the report header or report footer.
*/
published constants ReportPrintOption
{
Modified: openoffice/trunk/main/offapi/com/sun/star/report/XSection.idl
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/report/XSection.idl?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/report/XSection.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/report/XSection.idl Sat Jun 8
20:30:34 2019
@@ -114,7 +114,7 @@ published interface XSection
*/
[attribute,bound] string ConditionalPrintExpression;
- /** Specifies wether the section is printed on a separate page.
+ /** Specifies whether the section is printed on a separate page.
<p>Not valid for page header or page footer.</p>
@see ForceNewPage
*/
@@ -124,7 +124,7 @@ published interface XSection
get raises ( com::sun::star::beans::UnknownPropertyException );
};
- /** Specifies wether the section is printed in a new row or column within
a multi column report.
+ /** Specifies whether the section is printed in a new row or column within
a multi column report.
<p>Not valid for page header or page footer.</p>
@see ForceNewPage
*/
Modified: openoffice/trunk/main/offapi/com/sun/star/text/XTextTableCursor.idl
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/text/XTextTableCursor.idl?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/text/XTextTableCursor.idl
(original)
+++ openoffice/trunk/main/offapi/com/sun/star/text/XTextTableCursor.idl Sat Jun
8 20:30:34 2019
@@ -63,7 +63,7 @@ published interface XTextTableCursor: co
specifies the name of the cell to go to.
@param bExpand
- determines wether the selection is to be expanded.
+ determines whether the selection is to be expanded.
@see com::sun::star::text::Cell
*/
@@ -78,7 +78,7 @@ published interface XTextTableCursor: co
the number of cells to move.
@param bExpand
- determines wether the selection is to be expanded.
+ determines whether the selection is to be expanded.
*/
boolean goLeft( [in] short nCount,
[in] boolean bExpand );
@@ -91,7 +91,7 @@ published interface XTextTableCursor: co
the number of cells to move.
@param bExpand
- determines wether the selection is to be expanded.
+ determines whether the selection is to be expanded.
*/
boolean goRight( [in] short nCount,
[in] boolean bExpand );
@@ -104,7 +104,7 @@ published interface XTextTableCursor: co
the number of cells to move.
@param bExpand
- determines wether the selection is to be expanded.
+ determines whether the selection is to be expanded.
*/
boolean goUp( [in] short nCount,
[in] boolean bExpand );
@@ -117,7 +117,7 @@ published interface XTextTableCursor: co
the number of cells to move.
@param bExpand
- determines wether the selection is to be expanded.
+ determines whether the selection is to be expanded.
*/
boolean goDown( [in] short nCount,
[in] boolean bExpand );
@@ -127,7 +127,7 @@ published interface XTextTableCursor: co
/** moves the cursor to the top left cell of the table.
@param bExpand
- determines wether the selection is to be expanded.
+ determines whether the selection is to be expanded.
*/
void gotoStart( [in] boolean bExpand );
@@ -136,7 +136,7 @@ published interface XTextTableCursor: co
/** moves the cursor to the bottom right cell of the table.
@param bExpand
- determines wether the selection is to be expanded.
+ determines whether the selection is to be expanded.
*/
void gotoEnd( [in] boolean bExpand );
Modified:
openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs
(original)
+++
openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs
Sat Jun 8 20:30:34 2019
@@ -2500,42 +2500,42 @@
<prop oor:name="WarnSaveOrSendDoc"
oor:type="xs:boolean">
<info>
<author>GT</author>
- <desc>Specifies wether to warn
when saving or sending documents with personal/hidden data.</desc>
+ <desc>Specifies whether to warn
when saving or sending documents with personal/hidden data.</desc>
</info>
<value>false</value>
</prop>
<prop oor:name="WarnSignDoc"
oor:type="xs:boolean">
<info>
<author>GT</author>
- <desc>Specifies wether to warn
when signing documents with personal/hidden data.</desc>
+ <desc>Specifies whether to warn
when signing documents with personal/hidden data.</desc>
</info>
<value>true</value>
</prop>
<prop oor:name="WarnPrintDoc"
oor:type="xs:boolean">
<info>
<author>GT</author>
- <desc>Specifies wether to warn
when printing documents with personal/hidden data.</desc>
+ <desc>Specifies whether to warn
when printing documents with personal/hidden data.</desc>
</info>
<value>false</value>
</prop>
<prop oor:name="WarnCreatePDF"
oor:type="xs:boolean">
<info>
<author>GT</author>
- <desc>Specifies wether to warn
when creating PDF documents with personal/hidden data.</desc>
+ <desc>Specifies whether to warn
when creating PDF documents with personal/hidden data.</desc>
</info>
<value>false</value>
</prop>
<prop oor:name="RemovePersonalInfoOnSaving"
oor:type="xs:boolean">
<info>
<author>GT</author>
- <desc>Specifies wether to
remove personal information on saving.</desc>
+ <desc>Specifies whether to
remove personal information on saving.</desc>
</info>
<value>false</value>
</prop>
<prop oor:name="RecommendPasswordProtection"
oor:type="xs:boolean">
<info>
<author>GT</author>
- <desc>Specifies wether to
recommend password protection when saving documents.</desc>
+ <desc>Specifies whether to
recommend password protection when saving documents.</desc>
</info>
<value>false</value>
</prop>
@@ -3416,7 +3416,7 @@
<prop oor:name="ShowBasic" oor:type="xs:boolean">
<info>
<author>ABI</author>
- <desc>Determines wether basic help
should be shown.</desc>
+ <desc>Determines whether basic help
should be shown.</desc>
</info>
<value>true</value>
</prop>
Modified:
openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
(original)
+++
openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
Sat Jun 8 20:30:34 2019
@@ -314,7 +314,7 @@
<prop oor:name="IsUseCharacterVariants" oor:type="xs:boolean">
<!-- OldLocation: NEW -->
<info>
- <desc>Specifies wether Taiwan, Hongkong SAR, and
Macao SAR character variants should be used for translation.</desc>
+ <desc>Specifies whether Taiwan, Hongkong SAR, and
Macao SAR character variants should be used for translation.</desc>
<label>Use character variants</label>
</info>
<value>false</value>
@@ -322,7 +322,7 @@
<prop oor:name="IsTranslateCommonTerms" oor:type="xs:boolean">
<!-- OldLocation: NEW -->
<info>
- <desc>Specifies wether common terms should be
detected and translated as whole words.</desc>
+ <desc>Specifies whether common terms should be
detected and translated as whole words.</desc>
<label>Translate Common Terms</label>
</info>
<value>false</value>
Modified: openoffice/trunk/main/psprint_config/configuration/psprint.conf
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/psprint_config/configuration/psprint.conf?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/psprint_config/configuration/psprint.conf (original)
+++ openoffice/trunk/main/psprint_config/configuration/psprint.conf Sat Jun 8
20:30:34 2019
@@ -44,7 +44,7 @@
; if key is absent the default is 24
; ColorDepth=24
-; ColorDevice: the default setting wether the device is color capable
+; ColorDevice: the default setting whether the device is color capable
; possible values: 0: driver setting, -1: grey scale, 1: color
; if key is absent the default is 0
; ColorDepth=0
@@ -66,7 +66,7 @@
; Note: the following two key types are in the global section to provide
; defaults for newly added printers.
-; PerformFontSubstitution: wether to replace downloadable fonts
+; PerformFontSubstitution: whether to replace downloadable fonts
; with resident fonts or not
PerformFontSubstitution=false
@@ -118,7 +118,7 @@ Command=
; and therefore the application should not show its own dialog.
;Features=
-; PerformFontSubstitution: wether to replace downloadable fonts
+; PerformFontSubstitution: whether to replace downloadable fonts
; with resident fonts or not
PerformFontSubstitution=false
Modified: openoffice/trunk/main/pyuno/inc/pyuno/pyuno.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/pyuno/inc/pyuno/pyuno.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/pyuno/inc/pyuno/pyuno.hxx (original)
+++ openoffice/trunk/main/pyuno/inc/pyuno/pyuno.hxx Sat Jun 8 20:30:34 2019
@@ -84,7 +84,7 @@ namespace pyuno
/** Helper class for keeping references to python objects.
BEWARE: Look up every python function you use to check
- wether you get an acquired or not acquired object pointer
+ whether you get an acquired or not acquired object pointer
(python terminus for a not acquired object pointer
is 'borrowed reference'). Use in the acquired pointer cases the
PyRef( pointer, SAL_NO_ACQUIRE) ctor.
Modified: openoffice/trunk/main/reportdesign/source/core/sdr/UndoEnv.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/source/core/sdr/UndoEnv.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/source/core/sdr/UndoEnv.cxx (original)
+++ openoffice/trunk/main/reportdesign/source/core/sdr/UndoEnv.cxx Sat Jun 8
20:30:34 2019
@@ -340,7 +340,7 @@ void SAL_CALL OXUndoEnvironment::propert
implSetModified();
// now we have access to the cached info about the property affected
- // and are able to decide wether or not we need an undo action
+ // and are able to decide whether or not we need an undo action
// no UNDO for transient/readonly properties
if ( aPropertyPos->second.bIsReadonlyOrTransient )
Modified: openoffice/trunk/main/sal/osl/os2/file_url.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/file_url.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/file_url.cxx (original)
+++ openoffice/trunk/main/sal/osl/os2/file_url.cxx Sat Jun 8 20:30:34 2019
@@ -235,7 +235,7 @@ BOOL WINAPI IsValidFilePathComponent(
lpComponentEnd = lpCurrent;
}
- /* Test wether the component specifies a device name what is not
allowed */
+ /* Test whether the component specifies a device name what is not
allowed */
// MT: PERFORMANCE:
// This is very expensive. A lot of calls to _tcsicmp.
Modified: openoffice/trunk/main/sal/osl/os2/pipeimpl.h
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/pipeimpl.h?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/pipeimpl.h (original)
+++ openoffice/trunk/main/sal/osl/os2/pipeimpl.h Sat Jun 8 20:30:34 2019
@@ -44,7 +44,7 @@
// Because the value of an invalid HANDLE returned by API functions differs
// between different functions and differs on different Windows platforms,
-// this function checks wether the handle has a meaningful value.
+// this function checks whether the handle has a meaningful value.
#ifndef __cplusplus
#define IsValidHandle( handle ) ((DWORD)(handle) + 1 > 1)
Modified: openoffice/trunk/main/sal/osl/unx/thread.c
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/unx/thread.c?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/unx/thread.c (original)
+++ openoffice/trunk/main/sal/osl/unx/thread.c Sat Jun 8 20:30:34 2019
@@ -1003,7 +1003,7 @@ static void osl_thread_textencoding_init
/*
Tools string functions call abort() on an unknown encoding so ASCII
- is a meaningful fallback regardless wether the assertion makes sense.
+ is a meaningful fallback regardless whether the assertion makes sense.
*/
if ( RTL_TEXTENCODING_DONTKNOW == defaultEncoding )
Modified: openoffice/trunk/main/sal/osl/w32/file_url.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/file_url.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/file_url.cxx (original)
+++ openoffice/trunk/main/sal/osl/w32/file_url.cxx Sat Jun 8 20:30:34 2019
@@ -142,7 +142,7 @@ static BOOL IsValidFilePathComponent(
lpComponentEnd = lpCurrent;
}
- /* Test wether the component specifies a device name what is
not allowed */
+ /* Test whether the component specifies a device name what is
not allowed */
// MT: PERFORMANCE:
// This is very expensive. A lot of calls to _tcsicmp.
Modified: openoffice/trunk/main/sal/osl/w32/pipeimpl.h
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/pipeimpl.h?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/pipeimpl.h (original)
+++ openoffice/trunk/main/sal/osl/w32/pipeimpl.h Sat Jun 8 20:30:34 2019
@@ -50,7 +50,7 @@
// Because the value of an invalid HANDLE returned by API functions differs
// between different functions and differs on different Windows platforms,
-// this function checks wether the handle has a meaningful value.
+// this function checks whether the handle has a meaningful value.
#ifndef __cplusplus
#define IsValidHandle( handle ) ((DWORD)(handle) + 1 > 1)
Modified: openoffice/trunk/main/sd/source/ui/app/sdmod1.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/app/sdmod1.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/app/sdmod1.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/app/sdmod1.cxx Sat Jun 8 20:30:34 2019
@@ -573,7 +573,7 @@ SfxFrame* SdModule::ExecuteNewDocument(
{
//we start without wizard
- //check wether we should load a template document
+ //check whether we should load a template document
const ::rtl::OUString aServiceName(
RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.PresentationDocument" )
);
String aStandardTemplate(
SfxObjectFactory::GetStandardTemplate( aServiceName ) );
Modified: openoffice/trunk/main/sd/source/ui/dlg/TemplateScanner.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/dlg/TemplateScanner.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/dlg/TemplateScanner.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/dlg/TemplateScanner.cxx Sat Jun 8
20:30:34 2019
@@ -249,7 +249,7 @@ TemplateScanner::State TemplateScanner::
::ucbhelper::Content aContent = ::ucbhelper::Content (aId,
mxEntryEnvironment);
if (aContent.isDocument ())
{
- // Check wether the entry is an impress template. If so
+ // Check whether the entry is an impress template. If so
// add a new entry to the resulting list (which is created
// first if necessary).
if ( (sContentType ==
MIMETYPE_OASIS_OPENDOCUMENT_PRESENTATION_TEMPLATE)
Modified: openoffice/trunk/main/sd/source/ui/dlg/dlgass.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/dlg/dlgass.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/dlg/dlgass.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/dlg/dlgass.cxx Sat Jun 8 20:30:34 2019
@@ -628,7 +628,7 @@ AssistentDlgImpl::AssistentDlgImpl( ::Wi
UpdatePreview( sal_True );
- //check wether we should start with a template document initialy and
preselect it
+ //check whether we should start with a template document initialy and
preselect it
const ::rtl::OUString aServiceName( RTL_CONSTASCII_USTRINGPARAM(
"com.sun.star.presentation.PresentationDocument" ) );
String aStandardTemplate( SfxObjectFactory::GetStandardTemplate(
aServiceName ) );
if( aStandardTemplate.Len() )
Modified: openoffice/trunk/main/sd/source/ui/func/fupage.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/func/fupage.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/qa/complex/sfx2/DocumentInfo.java (original)
+++ openoffice/trunk/main/sfx2/qa/complex/sfx2/DocumentInfo.java Sat Jun 8
20:30:34 2019
@@ -60,7 +60,7 @@ public class DocumentInfo
{
m_xMSF = getMSF();
- System.out.println("check wether there is a valid
MultiServiceFactory");
+ System.out.println("check whether there is a valid
MultiServiceFactory");
assertNotNull("## Couldn't get MultiServiceFactory make sure your
Office is started", m_xMSF);
Modified: openoffice/trunk/main/sfx2/qa/complex/sfx2/GlobalEventBroadcaster.java
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/qa/complex/sfx2/GlobalEventBroadcaster.java?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/qa/complex/sfx2/GlobalEventBroadcaster.java
(original)
+++ openoffice/trunk/main/sfx2/qa/complex/sfx2/GlobalEventBroadcaster.java Sat
Jun 8 20:30:34 2019
@@ -59,7 +59,7 @@ public class GlobalEventBroadcaster {
@Before public void initialize() {
m_xMSF = getMSF();
- System.out.println("check wether there is a valid
MultiServiceFactory");
+ System.out.println("check whether there is a valid
MultiServiceFactory");
assertNotNull("## Couldn't get MultiServiceFactory make sure your
Office is started", m_xMSF);
@@ -79,7 +79,7 @@ public class GlobalEventBroadcaster {
System.out.println("... done");
- System.out.println("check wether the created instance is valid");
+ System.out.println("check whether the created instance is valid");
assertNotNull("couldn't create service", GlobalEventBroadcaster);
Modified: openoffice/trunk/main/sfx2/source/appl/appopen.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/appl/appopen.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/appl/appopen.cxx (original)
+++ openoffice/trunk/main/sfx2/source/appl/appopen.cxx Sat Jun 8 20:30:34 2019
@@ -828,7 +828,7 @@ void SfxApplication::OpenDocExec_Impl( S
if ( !rReq.IsSynchronCall() )
{
- // now check wether a stream is already there
+ // now check whether a stream is already there
// if not: download it in a thread and restart the call
// return;
}
Modified: openoffice/trunk/main/sfx2/source/control/dispatch.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/control/dispatch.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/control/dispatch.cxx (original)
+++ openoffice/trunk/main/sfx2/source/control/dispatch.cxx Sat Jun 8 20:30:34
2019
@@ -1785,7 +1785,7 @@ void SfxDispatcher::_Update_Impl( sal_Bo
if ( bReadOnlyShell && !( nPos &
SFX_VISIBILITY_READONLYDOC ) )
continue;
- // check wether toolbar needs activation of a special feature
+ // check whether toolbar needs activation of a special feature
sal_uInt32 nFeature = pIFace->GetObjectBarFeature(nNo);
if ( nFeature && !pShell->HasUIFeature( nFeature ) )
continue;
@@ -1842,7 +1842,7 @@ void SfxDispatcher::_Update_Impl( sal_Bo
if ( nFeature && !pShell->HasUIFeature( nFeature ) )
continue;
- // slot decides wether a ChildWindow is shown when document is OLE
server or OLE client
+ // slot decides whether a ChildWindow is shown when document is
OLE server or OLE client
sal_uInt16 nMode = SFX_VISIBILITY_STANDARD;
if( pSlot )
{
Modified: openoffice/trunk/main/sfx2/source/dialog/filedlghelper.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/dialog/filedlghelper.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/dialog/filedlghelper.cxx (original)
+++ openoffice/trunk/main/sfx2/source/dialog/filedlghelper.cxx Sat Jun 8
20:30:34 2019
@@ -592,7 +592,7 @@ void FileDialogHelper_Impl::updatePrevie
{
uno::Reference< XFilePickerControlAccess > xCtrlAccess(
mxFileDlg, UNO_QUERY );
- // check, wether or not we have to display a preview
+ // check, whether or not we have to display a preview
if ( xCtrlAccess.is() )
{
try
@@ -1624,7 +1624,7 @@ ErrCode FileDialogHelper_Impl::execute(
if ( rpURLList == NULL || rpURLList->GetObject(0) == NULL )
return ERRCODE_ABORT;
- // check, wether or not we have to display a password box
+ // check, whether or not we have to display a password box
if ( pCurrentFilter && mbHasPassword && mbIsPwdEnabled &&
xCtrlAccess.is() )
{
try
--- openoffice/trunk/main/canvas/source/directx/dx_surfacebitmap.hxx (original)
+++ openoffice/trunk/main/canvas/source/directx/dx_surfacebitmap.hxx Sat Jun 8
20:30:34 2019
@@ -127,7 +127,7 @@ namespace dxcanvas
// internal implementation of the iColorBuffer interface
canvas::IColorBufferSharedPtr mpColorBuffer;
// indicates wether the associated surface needs
// to refresh its contents or not. in other words,
// this flag is set iff both representations are
// out of sync.
Modified:
openoffice/trunk/main/chart2/source/controller/drawinglayer/DrawViewWrapper.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/controller/drawinglayer/DrawViewWrapper.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/chart2/source/controller/drawinglayer/DrawViewWrapper.cxx
(original)
+++
openoffice/trunk/main/chart2/source/controller/drawinglayer/DrawViewWrapper.cxx
Sat Jun 8 20:30:34 2019
@@ -281,7 +281,7 @@ void DrawViewWrapper::MarkObject( SdrObj
if( m_pMarkHandleProvider )
bFrameDragSingles = m_pMarkHandleProvider->getFrameDragSingles();
- this->SetFrameDragSingles(bFrameDragSingles);//decide wether each
single object should get handles
+ this->SetFrameDragSingles(bFrameDragSingles);//decide whether each
single object should get handles
this->SdrView::MarkObj( pObj, this->GetPageView() );
this->showMarkHandles();
}
Modified:
openoffice/trunk/main/chart2/source/controller/main/ChartController_Window.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/controller/main/ChartController_Window.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/chart2/source/controller/main/ChartController_Window.cxx
(original)
+++
openoffice/trunk/main/chart2/source/controller/main/ChartController_Window.cxx
Sat Jun 8 20:30:34 2019
@@ -246,7 +246,7 @@ const short HITPIX=2; //hit-tolerance in
Size aLogicSize = m_pChartWindow->PixelToLogic( Size( Width, Height ),
MapMode( MAP_100TH_MM ) );
bool bIsEmbedded = true;
//todo: for standalone chart: detect wether we are standalone
if( bIsEmbedded )
{
//change map mode to fit new size
Modified:
openoffice/trunk/main/chart2/source/controller/main/PositionAndSizeHelper.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/controller/main/PositionAndSizeHelper.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/chart2/source/controller/main/PositionAndSizeHelper.cxx
(original)
+++
openoffice/trunk/main/chart2/source/controller/main/PositionAndSizeHelper.cxx
Sat Jun 8 20:30:34 2019
@@ -58,7 +58,7 @@ bool PositionAndSizeHelper::moveObject(
if( OBJECTTYPE_TITLE==eObjectType )
{
//@todo decide wether x is primary or secondary
chart2::RelativePosition aRelativePosition;
aRelativePosition.Anchor = drawing::Alignment_CENTER;
//the anchor point at the title object is top/middle
@@ -69,7 +69,7 @@ bool PositionAndSizeHelper::moveObject(
}
else if( OBJECTTYPE_DATA_CURVE_EQUATION==eObjectType )
{
//@todo decide wether x is primary or secondary
chart2::RelativePosition aRelativePosition;
aRelativePosition.Anchor = drawing::Alignment_TOP_LEFT;
//the anchor point at the title object is top/middle
@@ -110,7 +110,7 @@ bool PositionAndSizeHelper::moveObject(
}
else if(OBJECTTYPE_DIAGRAM==eObjectType ||
OBJECTTYPE_DIAGRAM_WALL==eObjectType || OBJECTTYPE_DIAGRAM_FLOOR==eObjectType)
{
//@todo decide wether x is primary or secondary
//set position:
chart2::RelativePosition aRelativePosition;
Modified:
openoffice/trunk/main/chart2/source/controller/main/SelectionHelper.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/controller/main/SelectionHelper.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/controller/main/SelectionHelper.cxx
(original)
+++ openoffice/trunk/main/chart2/source/controller/main/SelectionHelper.cxx Sat
Jun 8 20:30:34 2019
@@ -271,7 +271,7 @@ void Selection::adaptSelectionToNewPos(
m_aSelectedOID = ObjectIdentifier( aPageCID );
}
- //check wether the diagram was hit but not selected (e.g.
because it has no filling):
+ //check whether the diagram was hit but not selected (e.g.
because it has no filling):
rtl::OUString aDiagramCID =
ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DIAGRAM,
rtl::OUString::valueOf( sal_Int32(0) ) );
rtl::OUString aWallCID(
ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DIAGRAM_WALL,
rtl::OUString() ) );//@todo read CID from model
bool bBackGroundHit = m_aSelectedOID.getObjectCID().equals(
aPageCID ) || m_aSelectedOID.getObjectCID().equals( aWallCID ) ||
!m_aSelectedOID.isAutoGeneratedObject();
@@ -288,7 +288,7 @@ void Selection::adaptSelectionToNewPos(
}
}
}
- //check wether the legend was hit but not selected (e.g.
because it has no filling):
+ //check whether the legend was hit but not selected (e.g.
because it has no filling):
if( bBackGroundHit || m_aSelectedOID.getObjectCID().equals(
aDiagramCID ) )
{
rtl::OUString aLegendCID(
ObjectIdentifier::createClassifiedIdentifierForParticle(
ObjectIdentifier::createParticleForLegend(0,0) ) );//@todo read CID from model
@@ -561,7 +561,7 @@ SdrObject* SelectionHelper::getObjectToM
E3dScene* SelectionHelper::getSceneToRotate( SdrObject* pObj )
{
//search wether the object or one of its children is a 3D object
//if so, return the accessory 3DScene
E3dObject* pRotateable = 0;
Modified:
openoffice/trunk/main/chart2/source/inc/chartview/ExplicitScaleValues.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/inc/chartview/ExplicitScaleValues.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/inc/chartview/ExplicitScaleValues.hxx
(original)
+++ openoffice/trunk/main/chart2/source/inc/chartview/ExplicitScaleValues.hxx
Sat Jun 8 20:30:34 2019
@@ -108,13 +108,13 @@ struct OOO_DLLPUBLIC_CHARTVIEW ExplicitI
before a scaling is applied, which may lead to non equidistant tickmarks
on the screen.</p>
- <p><member>PostEquidistant</member> rules wether the
<member>Distance</member>
+ <p><member>PostEquidistant</member> rules whether the
<member>Distance</member>
is meant to be a value before or after scaling.</p>
*/
double Distance;
/**
- <member>PostEquidistant</member> rules wether the member
<member>Distance</member>
+ <member>PostEquidistant</member> rules whether the member
<member>Distance</member>
describes a distance before or after the scaling is applied.
<p>If <member>PostEquidistant</member> equals <TRUE/>
@@ -127,7 +127,7 @@ namespace dxcanvas
// internal implementation of the iColorBuffer interface
canvas::IColorBufferSharedPtr mpColorBuffer;
- // indicates wether the associated surface needs
+ // indicates whether the associated surface needs
// to refresh its contents or not. in other words,
// this flag is set iff both representations are
@@ -246,7 +246,7 @@ const short HITPIX=2; //hit-tolerance in
MapMode( MAP_100TH_MM ) );
bool bIsEmbedded = true;
- //todo: for standalone chart: detect wether we are standalone
+ //todo: for standalone chart: detect whether we are standalone
if( bIsEmbedded )
{
@@ -58,7 +58,7 @@ bool PositionAndSizeHelper::moveObject(
if( OBJECTTYPE_TITLE==eObjectType )
{
- //@todo decide wether x is primary or secondary
+ //@todo decide whether x is primary or secondary
chart2::RelativePosition aRelativePosition;
aRelativePosition.Anchor = drawing::Alignment_CENTER;
@@ -69,7 +69,7 @@ bool PositionAndSizeHelper::moveObject(
else if( OBJECTTYPE_DATA_CURVE_EQUATION==eObjectType )
{
- //@todo decide wether x is primary or secondary
+ //@todo decide whether x is primary or secondary
chart2::RelativePosition aRelativePosition;
aRelativePosition.Anchor = drawing::Alignment_TOP_LEFT;
@@ -110,7 +110,7 @@ bool PositionAndSizeHelper::moveObject(
OBJECTTYPE_DIAGRAM_WALL==eObjectType || OBJECTTYPE_DIAGRAM_FLOOR==eObjectType)
{
- //@todo decide wether x is primary or secondary
+ //@todo decide whether x is primary or secondary
//set position:
chart2::RelativePosition aRelativePosition;
@@ -561,7 +561,7 @@ SdrObject* SelectionHelper::getObjectToM
E3dScene* SelectionHelper::getSceneToRotate( SdrObject* pObj )
{
- //search wether the object or one of its children is a 3D object
+ //search whether the object or one of its children is a 3D object
//if so, return the accessory 3DScene
E3dObject* pRotateable = 0;
<member>Distance</member>
Modified: openoffice/trunk/main/chart2/source/model/main/ChartModel.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/model/main/ChartModel.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/func/fupage.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/func/fupage.cxx Sat Jun 8 20:30:34 2019
@@ -358,7 +358,7 @@ const SfxItemSet* FuPage::ExecuteDialog(
bool bSetToAllPages = false;
- // Ask, wether the setting are for the background-page
or for the current page
+ // Ask, whether the setting are for the background-page
or for the current page
if( !mbMasterPage && bChanges )
{
// But don't ask in notice-view, because we
can't change the background of
Modified:
openoffice/trunk/main/sd/source/ui/slidesorter/cache/SlsQueueProcessorThread.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/cache/SlsQueueProcessorThread.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/sd/source/ui/slidesorter/cache/SlsQueueProcessorThread.hxx
(original)
+++
openoffice/trunk/main/sd/source/ui/slidesorter/cache/SlsQueueProcessorThread.hxx
Sat Jun 8 20:30:34 2019
@@ -88,7 +88,7 @@ protected:
virtual void SAL_CALL onTerminated (void);
private:
- /** Flag that indicates wether the onTerminated method has been
already
+ /** Flag that indicates whether the onTerminated method has been
already
called. If so then a subsequent call to detach deletes the thread.
*/
volatile bool mbIsTerminated;
Modified:
openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsButtonBar.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsButtonBar.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsButtonBar.hxx
(original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsButtonBar.hxx
Sat Jun 8 20:30:34 2019
@@ -171,7 +171,7 @@ private:
/** Remember the specified page. If it differs from mpDescriptor then
the buttons are placed anew.
@return
- The returned flag indicates wether the mpDescriptor member
+ The returned flag indicates whether the mpDescriptor member
is set to a new value.
*/
bool SetPage (const model::SharedPageDescriptor& rpDescriptor);
Modified:
openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsInsertAnimator.hxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsInsertAnimator.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
---
openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsInsertAnimator.hxx
(original)
+++
openoffice/trunk/main/sd/source/ui/slidesorter/inc/view/SlsInsertAnimator.hxx
Sat Jun 8 20:30:34 2019
@@ -50,7 +50,7 @@ public:
enum ResetMode { RM_Normal, RM_AbortAnimations };
/** Restore the normal position of all page objects.
@param eMode
- This flag controls wether to start an animation that ends in the
+ This flag controls whether to start an animation that ends in the
normal positions of all slides (AM_Animated) or to restore the
normal positions immediately (AM_Immediate).
*/
Modified:
openoffice/trunk/main/sdext/source/pdfimport/tree/writertreevisiting.cxx
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sdext/source/pdfimport/tree/writertreevisiting.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sdext/source/pdfimport/tree/writertreevisiting.cxx
(original)
+++ openoffice/trunk/main/sdext/source/pdfimport/tree/writertreevisiting.cxx
Sat Jun 8 20:30:34 2019
@@ -991,7 +991,7 @@ void WriterXmlFinalizer::visit( Paragrap
}
// check whether to leave some space to next paragraph
// find wether there is a next paragraph
std::list< Element* >::const_iterator it = rParentIt;
const ParagraphElement* pNextPara = NULL;
while( ++it != elem.Parent->Children.end() && ! pNextPara )
@@ -991,7 +991,7 @@ void WriterXmlFinalizer::visit( Paragrap
}
// check whether to leave some space to next paragraph
- // find wether there is a next paragraph
+ // find whether there is a next paragraph
std::list< Element* >::const_iterator it = rParentIt;
const ParagraphElement* pNextPara = NULL;
Modified: openoffice/trunk/main/sfx2/qa/complex/sfx2/DocumentInfo.java
URL:
http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/qa/complex/sfx2/DocumentInfo.java?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================